==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyLenClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyLenClass

// class file dependencies
// @dep_class 9fdd78bba71b153a gnu_xml_xpath_XPathParser__24YyLenClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyLenClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyLenClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$object	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct {
	_jc_short_array	*yyLen;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyLenClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyLenClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods	gnu_xml_xpath_XPathParser__24YyLenClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs	gnu_xml_xpath_XPathParser__24YyLenClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyLenClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyLenClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyLenClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyLenClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyLenClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyLenClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyLenClass

// class file dependencies
// @dep_class 9fdd78bba71b153a gnu_xml_xpath_XPathParser__24YyLenClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyLenClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyLenClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$object	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct {
	_jc_short_array	*yyLen;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyLenClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyLenClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyLenClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vmethods	gnu_xml_xpath_XPathParser__24YyLenClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_refs	gnu_xml_xpath_XPathParser__24YyLenClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyLenClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyLenClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyLenClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyLenClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyLenClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyLenClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyLenClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyLenClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyLenClass_H_ */
